OptimizerMixin - Qudas 0.1.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# OptimizerMixin

class qudas.pipeline.steps.OptimizerMixin

  パイプラインステップ内で使用する最適化処理用のMixinクラス。 このMixinクラスは、transform および optimize メソッドをサポートし、optimize メソッドの実装を必須とします。

  abstract optimize(X: Any | None = None, y: Any | None = None, **fit_params) → Any

    抽象的な最適化メソッド。

    Parameters:

      - X (Any) – 入力データ。

      - y (Any) – ターゲットデータ。

      - **fit_params – 追加のパラメータ。

    Returns:

      最適化結果。

    Return type:

      Any

  transform(X: Any) → Any

    オプションの変換メソッド。サブクラスでオーバーライド可能。

    Parameters:

      X (Any) – 入力データ。

    Returns:

      変換後のデータ。

    Return type:

      Any